@@ -6,7 +6,7 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use std::cmp;
+use std::{cmp, collections::BTreeSet};
 
 use crate::messaging::{
     system::{KeyedSig, MembershipState, NodeState, Proposal, SectionAuth},
@@ -113,7 +113,7 @@ impl Core {
         commands.extend(result);
         commands.push(self.send_node_approval(new_info)?);
 
-        self.print_network_stats().await;
+        self.print_network_stats();
 
         Ok(commands)
     }
@@ -167,7 +167,9 @@ impl Core {
         if equal_or_extension {
             // Our section or sub-section
             let signed_section_auth = SectionAuth::new(section_auth, sig.clone());
-            let infos = self.section.promote_and_demote_elders(&self.node.name());
+            let infos = self
+                .section
+                .promote_and_demote_elders(&self.node.name(), &BTreeSet::new());
             if !infos.contains(&signed_section_auth.value.elder_candidates()) {
                 // SectionInfo out of date, ignore.
                 return Ok(vec![]);
